@@ -515,6 +515,14 @@ impl Session {
                     name.as_ptr() as _,
                 )
             },
+            SshOption::PublicKeyAcceptedTypes(name) => unsafe {
+                let name = CString::new(name)?;
+                sys::ssh_options_set(
+                    **sess,
+                    sys::ssh_options_e::SSH_OPTIONS_PUBLICKEY_ACCEPTED_TYPES,
+                    name.as_ptr() as _,
+                )
+            },
             SshOption::AddIdentity(name) => unsafe {
                 let name = CString::new(name)?;
                 sys::ssh_options_set(
@@ -1153,6 +1161,10 @@ pub enum SshOption {
     Timeout(Duration),
 
     IdentityAgent(Option<String>),
+    /// Set the preferred public key algorithms to be used for
+    /// authentication as a comma-separated list). ex:
+    /// ssh-rsa,rsa-sha2-256,ssh-dss,ecdh-sha2-nistp256
+    PublicKeyAcceptedTypes(String),
 }
 
 /// Indicates the state of known-host matching, an important set
